      <section class="colorpicker-wrapper">
        {% include "django/forms/widgets/input.html" %}
        <!--- wtf -->
        <span></span>
        <div class="color-picker">
          <div class="picker-placeholder"></div>
        </div>
      </section>
