{% if button.label %}
<a class="btn btn-{{ button.button_style }} btn-lg" href="{{button.link.get_url}}" {% if button.new_tab %}target="_blank" rel="noopener noreferrer"{% endif %} aria-label="{{ button.label }}">
	<small>{{ button.label }}</small>
</a>
{% endif %}
