.quotes-block-wrapper{
	@extend .coyote-block-wrapper;
	position: relative;
	overflow: hidden;
	.rich-text{
		h1, h2, h3, h4, h5, p{
			&:last-child{
				margin-bottom: 0;
			}
		}
	}
	.tns-ovh{
		overflow: visible !important;
	}
	svg.svg{
		width: 400px;
		display: block;
		position: absolute;
		opacity: .2;
		@media screen and (max-width: 991px){
			width: 200px;
		}
		path{
			fill: var(--counter-color);
		}
		&.svg-left{
			transform: translateY(15%) translateX(-20%) rotate(45deg);
			left: 0;
			top: ($cy-spacer * -3);
			@media screen and (max-width: 991px){
				top: ($cy-spacer * -1);
				transform: translateY(0) translateX(-30%) rotate(45deg);
			}
		}
		&.svg-right{
			transform: translateY(-15%) translateX(20%) rotate(45deg);
			right: 0;
			bottom: ($cy-spacer * -3);
			@media screen and (max-width: 991px){
				bottom: ($cy-spacer * -1);
				transform: translateY(0) translateX(30%) rotate(45deg);
			}
		}
	}
	.tns-nav{
		position: absolute;
		bottom: -3rem;
		left: 50%;
		transform: translateX(-50%) translateY(100%);
		column-gap: 1rem;
		row-gap: 1rem;
		display: flex;
		button{
			background: var(--counter-color);
			border: 0 !important;
			height: .5rem;
			width: 2rem;
			border-radius: 30px;
			opacity: .3;
			transition: .2s ease;

			&.tns-nav-active{
				opacity: 1;
			}
		}
	}
	.quotes_wrapper{
		.quote{
			transition: .5s ease;
			&:not(.tns-slide-active){
				opacity: .5;
			}
			.person-image{
				border-radius: 100%;
			}
			.quotes-inner{
				max-width: 750px;
				margin-left: auto;
				margin-right: auto;
				text-align: center;
				h4{
					font-weight: 400;					
				}
			}
		}
	}
}