.coyote-category-block{
	@extend .coyote-block-wrapper;
	background: linear-gradient(-45deg, var(--contrast-color) 50%, var(--background) 50%) !important;
	.category-wrapper{
		.category-inner{
			padding: 1rem;
			background: var(--icon-block-background);
			color: var(--icon-block-color);
			border-radius: $border-radius;
		}
		.category-title{
			white-space: nowrap;
			overflow: hidden;
			width: 100%;
			text-overflow: ellipsis;
		}
		a{
			text-decoration: unset;
			color: var(--icon-block-color);
		}
	}
	.rich-text{
		h1, h2, h3, h4{
			i{
				color: $primary;
				font-style: unset;
			}
		}
	}
	.stock_price{
		*{
			color: inherit;
		}
		.second-session-price{
			display: none;
		}
	}
	&.layout2{
		.category-block{
			text-decoration: unset;
			color: inherit;
			display: block;
			border-bottom-left-radius: $border-radius;
			border-bottom-right-radius: $border-radius;
			overflow: hidden;
			img{
				border-bottom-left-radius: 0;
				border-bottom-right-radius: 0;
			}
			.bottom-wrapper{
				position: relative;
				background: var(--background);
				padding: .75rem 1rem;
				h5{
					width: 100%;
					white-space: nowrap;
					overflow: hidden;
					text-overflow: ellipsis;
				}
			}
		}
	}
}