.accordion-block-wrapper{
	@extend .coyote-block-wrapper;
	.accordion{
		.accordion-item{
			border-radius: 0 !important;
			border: 0;
			border-bottom: 3px solid var(--counter-color);
			background: transparent !important;
			.accordion-header{
				cursor: pointer;
			}
			.accordion-body{
				padding-top: 0;
			}
			.accordion-body, .accordion-header{
				padding-left: 0;
				padding-right: 0;
			}
		}
	}
}