{% load wagtailcore_tags %}
<section class="products-block {{ self.layout }} {{self.coyote_bg}}" id="{{ self.coyote_anchor }}">
	<div class="container">
		<div class="row">
			<div class="col-lg-{% if self.layout == 'layout1' %}5 me-auto{% else %}7 mx-auto text-center{% endif %} pe-lg-5{% if self.body %} mb-5{% endif %}">
				{{ self.body|richtext }}
				{% if self.layout == 'layout1' and self.read_more_button %}
					<div class="buttons-wrapper">
						<a class="btn btn-primary" href="{{ self.read_more_link }}">{{ self.read_more_button }}</a>
					</div>
				{% endif %}
			</div>
			<div class="col-lg-{% if self.layout == 'layout1' %}7{% else %}12{% endif %} coyote-slider">
				<div class="coyote-product-block-slider{% if self.layout == 'layout2' %}2{% endif %}">
					{% for product in self.products %}
						{% if product is not None %}
							<div class="product-wrapper">
								{% include "coyote/partials/product_slider_item.html" %}
							</div>
						{% endif %}
					{% endfor %}
				</div>
			</div>
			{% if self.layout == 'layout2' and self.read_more_button %}
				<div class="col-lg-12 text-center buttons-wrapper">
					<a class="btn btn-primary" href="{{ self.read_more_link }}">{{ self.read_more_button }}</a>
				</div>
			{% endif %}
		</div>
	</div>
</section>