# Generated by Django 3.2.23 on 2023-11-13 15:12

from django.db import migrations


class Migration(migrations.Migration):

    dependencies = [
        ('coyote', '0007_auto_20231113_1608'),
    ]

    operations = [
        migrations.RenameField(
            model_name='colorsetting',
            old_name='body_bg',
            new_name='body_background',
        ),
    ]
