.info-block-wrapper{
	background-color: #27382A;
	color: white;
	@extend .coyote-block-wrapper;
	.main-info{
		text-align: center;
		width: 50%;
		h4{
			font-size: ($cy-font-size * 2.5);
		}
	}

	.blokje-info{
		border: 2px solid $primary;
		transition: .4s ease-in-out;
		padding-top: ($cy-spacer * 1);
		a{
			text-decoration: none;
		}
		&:hover{
			border-color: white;
		}
	}
	.blokje-wrapper{
		grid-column-gap: 30px;
		grid-row-gap: 30px;
		grid-template-rows: auto;
		grid-template-columns: 1fr 1fr 1fr;
		grid-auto-columns: 1fr;
		display: grid;
		overflow: auto;
		scroll-snap-type: y mandatory;
		padding-top: ($cy-spacer * 1);
		padding-bottom: ($cy-spacer * 1);
	}

	.blokje-info {
		scroll-snap-align: start;
	}
	a:hover{
		text-decoration: underline;
	}
}
