.call_to_action{
	$cta_background: $primary;
	margin-top: -11rem;
	padding-top: $cy-spacer;
	padding-bottom: $cy-spacer;
	background: linear-gradient(to bottom, transparent 11rem, $footer-bg 11rem);
	position: relative;
	& > .container{
		position: relative;
		.container-inner{
			border-radius: $border-radius;
			overflow: hidden;
			background: $cta_background;
			color: color-contrast($cta_background);
		}
		& > i{
			content: "";
			position: absolute;
			top: 0;
			left: 50%;
			transform: translate(-50%, -50%);
			width: 6rem;
			height: 6rem;
			background: $cta_background;
			border-radius: 100%;
			color: color-contrast($cta_background);
			display: flex;
			flex-direction: column;
			justify-content: center;
			align-items: center;
			z-index: 3;
			font-size: 3rem;
		}
	}
}