# Generated by Django 4.2.11 on 2024-03-27 14:54

from django.db import migrations
import ocyan.plugin.coyote.fields


class Migration(migrations.Migration):

    dependencies = [
        ("coyote", "0012_auto_20240308_0914"),
    ]

    operations = [
        migrations.AlterField(
            model_name="coyotecontactpage",
            name="content",
            field=ocyan.plugin.coyote.fields.CoyoteStreamField(
                (), blank=True, use_json_field=True, verbose_name="Inhoud"
            ),
        ),
        migrations.AlterField(
            model_name="coyotecontactpage",
            name="footer",
            field=ocyan.plugin.coyote.fields.CoyoteStreamField(
                (), blank=True, use_json_field=True, verbose_name="Footer"
            ),
        ),
        migrations.AlterField(
            model_name="coyotecontactpage",
            name="header",
            field=ocyan.plugin.coyote.fields.CoyoteStreamField(
                (), blank=True, use_json_field=True, verbose_name="Header"
            ),
        ),
        migrations.AlterField(
            model_name="coyotehomepage",
            name="content",
            field=ocyan.plugin.coyote.fields.CoyoteStreamField(
                (), blank=True, use_json_field=True, verbose_name="Inhoud"
            ),
        ),
        migrations.AlterField(
            model_name="coyotehomepage",
            name="footer",
            field=ocyan.plugin.coyote.fields.CoyoteStreamField(
                (), blank=True, use_json_field=True, verbose_name="Footer"
            ),
        ),
        migrations.AlterField(
            model_name="coyotehomepage",
            name="header",
            field=ocyan.plugin.coyote.fields.CoyoteStreamField(
                (), blank=True, use_json_field=True, verbose_name="Header"
            ),
        ),
    ]
