{% load ocyan_thumbnail wagtailcore_tags styling_tags %}
<section class="content-wrapper">
	{% responsive_image self.image.file alt=self.image.title classes="image-left" %}
	<div class="container">
		<div class="row">
			<div class="col-lg-6 ms-auto">
				<div class="content-image-text">
					<h2>{{ self.title }}</h2>
					<p>{{ self.body|richtext }}</p>
					{% if self.buttons %}
					<div class="buttons-wrapper">
						{% for button in self.buttons %}
							{% include "coyote/blocks/partials/button.html" %}
						{% endfor %}
					</div>
					{% endif %}
				</div>
			</div>
		</div>
	</div>
</section>