# Generated by Django 4.2.11 on 2025-04-30 12:08

from django.db import migrations, models
from oxyan.themes.definitions import theme


class Migration(migrations.Migration):

    dependencies = [
        ("coyote", "0016_alter_stylesettings_header_font_variant_and_more"),
    ]

    operations = [
        migrations.AddField(
            model_name="stylesettings",
            name="body_color",
            field=models.CharField(default=theme["body-color"], max_length=7),
        ),
        migrations.AddField(
            model_name="stylesettings",
            name="border_radius",
            field=models.DecimalField(decimal_places=2, default=theme["border-radius"], max_digits=6),
        ),
    ]
