.products-block{
	@extend .coyote-block-wrapper;
	.coyote-product-block-slider, .coyote-product-block-slider2{
		.product-wrapper{
			.product{
				.product-description{
					display: none;
				}
				.add_to_basket_form_compact{
					display: none;
				}
				.product-rating{
					display: none;
				}
				.product-image{
					background: white;
					&:before{
						padding-top: 200px;
					}
					img{
						object-fit: contain;
						height: 100%;
						width: 100%;
					}
				}
				.product-title, .stock_price *{
					color: inherit;
				}
			}
		}
	}
	.rich-text{
		h1, h2, h3, h4{
			i{
				color: $primary;
				font-style: unset;
			}
		}
	}
}