{% load wagtailcore_tags %}

<section class="call_to_action">
	<div class="container">
	<i class="fa fa-{{ self.icon }}"></i>
		<div class="container-inner p-lg-5 px-3">
			<div class="row py-5">
				<div class="col-lg-8 mx-auto text-center">
					{% if self.header %}
						<h2 class="mb-0 d-lg-block d-none">{{ self.header }}</h2>
						<h3 class="mb-0 d-lg-none">{{ self.header }}</h2>
					{% endif %}
					<div class="mt-4">{{ self.body }}</div>
					{% if self.button %}
						<div class="buttons-wrapper">
							{% include "coyote/blocks/partials/button.html" with button=self.button %}
						</div>
					{% endif %}
				</div>
			</div>
		</div>
	</div>
</section>