@keyframes fade-up{from{transform:translateY(30px);opacity:0}to{transform:translateY(0);opacity:1}}@keyframes fade-in{from{opacity:0}to{opacity:1}}@keyframes overlay{from{transform:scale(1.2);opacity:0}to{transform:translateY(1);opacity:1}}.coyote-block-wrapper,.info-block-wrapper{padding-top:9rem;padding-bottom:9rem}@media screen and (max-width: 991px){.coyote-block-wrapper,.info-block-wrapper{padding-top:3rem;padding-bottom:3rem}}.content-wrapper{position:relative}@media screen and (min-width: 991px){.content-wrapper .image-left{position:absolute;top:0;left:0;width:50vw;height:100%;object-fit:cover;border-top-left-radius:0;border-bottom-left-radius:0}}@media screen and (max-width: 991px){.content-wrapper .image-left{width:100%;height:auto}}.content-wrapper .content-image-text{padding-top:9rem;padding-bottom:9rem;padding-left:9rem}.content-wrapper .content-image-text h2{font-weight:700;line-height:1.2em}.content-wrapper .content-image-text p{color:#526e6d;max-width:500px}@media screen and (max-width: 991px){.content-wrapper .content-image-text{padding:3rem;top:0}}.content-wrapper .content-image-text .btn-primary{border-radius:.75rem}.info-block-wrapper{background-color:#27382A;color:white}.info-block-wrapper .main-info{text-align:center;width:50%}.info-block-wrapper .main-info h4{font-size:2.5rem}.info-block-wrapper .blokje-info{border:2px solid #4b9e52;transition:.4s ease-in-out;padding-top:3rem}.info-block-wrapper .blokje-info a{text-decoration:none}.info-block-wrapper .blokje-info:hover{border-color:white}.info-block-wrapper .blokje-wrapper{grid-column-gap:30px;grid-row-gap:30px;grid-template-rows:auto;grid-template-columns:1fr 1fr 1fr;grid-auto-columns:1fr;display:grid;overflow:auto;scroll-snap-type:y mandatory;padding-top:3rem;padding-bottom:3rem}.info-block-wrapper .blokje-info{scroll-snap-align:start}.info-block-wrapper a:hover{text-decoration:underline}
