<div class="coyote_field {% if child.block.required %}required{% endif %}" data-contentpath="{{ child.block.name }}" style="display: flex; user-select: none;">
    {{ child.render_form }}
    {% if child.block.label %}
        <label class="coyote_field__label" {% if child.id_for_label %}for="{{ child.id_for_label }}"{% endif %} style="width: 100%; padding: 0; padding-left: 5px;">{{ child.block.label }}</label>
    {% endif %}
</div>