.image_with_text{
	@extend .coyote-block-wrapper;
	.layout-image{
        position: relative;
        @media screen and (max-width: 991px){
        	min-height: 200px;
        }
        img.img-fill{
            position: absolute;
            top: 0;
            left: 0;
            width: 100%;
            height: 100%;
            object-fit: cover;
        	@media screen and (max-width: 991px){
        		padding-left: calc(var(--bs-gutter-x) * .5);
        		padding-right: calc(var(--bs-gutter-x) * .5);
        	}
        }
    }
	&.layout2{
		.layout-image{
			@media screen and (min-width: 991px){
				order: 2;
				margin-left: auto;
			}
			img{
                right: 0;
                left: unset;
            }
		}
		.layout-lead{
			@media screen and (min-width: 991px){
				order: 1;
				.lead-wrapper{
					padding-right: 5rem;
				}
			}
		}
	}
	&.layout1{
		.layout-image{
			@media screen and (min-width: 991px){
				margin-right: auto;
			}
		}
		.layout-lead{
			@media screen and (min-width: 991px){
				order: 1;
				.lead-wrapper{
					padding-left: 5rem;
				}
			}
		}
	}
	.layout-image{
		@media screen and (max-width: 991px){
			margin-bottom: 2rem;
		}
	}
	.layout-lead{
		.lead-wrapper{
			height: 100%;
			display: flex;
			flex-direction: column;
			justify-content: space-between;
		}
		.counter{
			h2{
				color: var(--counter-color);
				@media screen and (min-width: 991px){
					font-size: 4rem;
					font-weight: 700;
				}
				@media screen and (max-width: 991px){
					font-size: 3rem;
					font-weight: 600;
				}
			}
		}
	}
}