{% load wagtailcore_tags ocyan_thumbnail %}
<section class="persons-block {{self.coyote_bg}}" id="{{ self.coyote_anchor }}">
	<div class="container">
		<div class="row">
			<div class="col-lg-7 mx-auto text-center {% if self.body %}mb-5{% endif %}">
				{{ self.body|richtext }}
			</div>
		</div>
		<div class="row css-slider">
			{% for person in self.persons %}
			<div class="col-xl-4 col-lg-6 mb-3">
				<div class="person">
					<div class="person-image">
						{% lazy_responsive_image person.image.file classes="background-image" %}
					</div>
					<div class="info-block">
						<div class="info-block-inner">
							<h4 class="mb-0">{{ person.name }}</h4>
							<h5 class="mt-1 mb-3">{{ person.function }}</h5>
							<div class="d-flex gap-3">
								{% if person.instagram %}<a href="{{ person.instagram }}" target="_blank"><i class="fa fa-instagram"></i></a>{% endif %}
								{% if person.facebook %}<a href="{{ person.facebook }}" target="_blank"><i class="fa fa-facebook"></i></a>{% endif %}
								{% if person.linkedin %}<a href="{{ person.linkedin }}" target="_blank"><i class="fa fa-linkedin"></i></a>{% endif %}
								{% if person.twitter %}<a href="{{ person.twitter }}" target="_blank"><i class="fa fa-twitter"></i></a>{% endif %}
							</div>
						</div>
					</div>
				</div>
			</div>
			{% endfor %}
		</div>
	</div>
</section>