from django.db import migrations, models
from oxyan.themes.definitions import theme


class Migration(migrations.Migration):

    dependencies = [
        ("coyote", "0013_alter_coyotecontactpage_content_and_more"),
    ]

    operations = [
        migrations.RemoveField(
            model_name="stylesettings",
            name="site",
        ),
        migrations.AlterField(
            model_name="stylesettings",
            name="body_background",
            field=models.CharField(default=theme["body-background"], max_length=7),
        ),
        migrations.AlterField(
            model_name="stylesettings",
            name="footer_background",
            field=models.CharField(default=theme["footer-background"], max_length=7),
        ),
        migrations.AlterField(
            model_name="stylesettings",
            name="gray_200",
            field=models.CharField(default=theme["gray-200"], max_length=7),
        ),
        migrations.AlterField(
            model_name="stylesettings",
            name="gray_900",
            field=models.CharField(default=theme["gray-900"], max_length=7),
        ),
        migrations.AlterField(
            model_name="stylesettings",
            name="header_background",
            field=models.CharField(default=theme["header-background"], max_length=7),
        ),
    ]
