# Generated by Django 4.2.11 on 2025-05-20 07:25

from django.db import migrations, models
from django.conf import settings
from oxyan.themes.definitions import theme


class Migration(migrations.Migration):

    dependencies = [
        ("coyote", "0019_auto_20250512_1642"),
    ]

    operations = [
        migrations.AddField(
            model_name="stylesettings",
            name="header",
            field=models.CharField(max_length=255, null=True, default=theme.get("header", "basic"), choices=settings.OXYAN_HEADER_OPTIONS),
        ),
    ]
