<section class="textlist coyote-block-wrapper {{self.coyote_bg}}" id="{{ self.coyote_anchor }}">
	<div class="container">
		<div class="row">
			<div class="col-lg-6 col-12{% if self.layout == 'layout1' %} mb-lg-0{% endif %}">
				<div {% if self.layout == 'layout1' %}class="position-sticky top-5"{% endif %}>
					{{ self.body }}
					{% if self.buttons and self.layout == 'layout1' %}
					<div class="buttons-wrapper">
						{% for button in self.buttons %}
							{% include "coyote/blocks/partials/button.html" with button=button %}
						{% endfor %}
					</div>
					{% endif %}
				</div>
			</div>
			<div class="{% if self.layout == 'layout1' %}col-lg-5{% endif %} col-12 ms-auto">
				<div class="row list-wrapper">
				{% for block in self.body_list %}
					<div class="{% if self.layout == 'layout1' %}col-12 {% elif self.layout == 'layout2' %}col-lg-4{% elif self.layout == 'layout3' %}col-lg-6{% endif %}">
						<div class="{% if not self.layout == 'layout1' %}pe-lg-3{% endif %}">
							{{ block }}
						</div>
					</div>
				{% endfor %}
				</div>
			</div>
			{% if self.buttons and not self.layout == 'layout1' %}
			<div class="buttons-wrapper">
				{% for button in self.buttons %}
					{% include "coyote/blocks/partials/button.html" with button=button %}
				{% endfor %}
			</div>
			{% endif %}
		</div>
	</div>
</section>
