# Generated by Django 4.2.11 on 2025-02-18 15:42

from django.db import migrations, models, utils
import django.db.models.deletion


def get_default_site_id():
    from wagtail.models import Site
    try:
        return Site.objects.get(is_default_site=True).id
    except Site.DoesNotExist:
        return Site.objects.first().id


class Migration(migrations.Migration):

    dependencies = [
        ("wagtailcore", "0094_alter_page_locale"),
        ("coyote", "0014_remove_stylesettings_site_and_more"),
    ]

    operations = [
        migrations.AddField(
            model_name="stylesettings",
            name="header_font",
            field=models.CharField(blank=True, max_length=255, null=True),
        ),
        migrations.AddField(
            model_name="stylesettings",
            name="header_font_family",
            field=models.CharField(blank=True, max_length=255, null=True),
        ),
        migrations.AddField(
            model_name="stylesettings",
            name="header_font_variant",
            field=models.CharField(blank=True, max_length=255, null=True),
        ),
        migrations.AddField(
            model_name="stylesettings",
            name="paragraph_font",
            field=models.CharField(blank=True, max_length=255, null=True),
        ),
        migrations.AddField(
            model_name="stylesettings",
            name="paragraph_font_family",
            field=models.CharField(blank=True, max_length=255, null=True),
        ),
        migrations.AddField(
            model_name="stylesettings",
            name="paragraph_font_variant",
            field=models.CharField(blank=True, max_length=255, null=True),
        ),
        migrations.AddField(
            model_name="stylesettings",
            name="site",
            field=models.OneToOneField(
                default=get_default_site_id,
                editable=False,
                on_delete=django.db.models.deletion.CASCADE,
                to="wagtailcore.site",
            ),
            preserve_default=False,
        ),
    ]
