{% if font_settings.header_font_family or font_settings.paragraph_font_family %}
<link rel="preconnect" href="https://fonts.googleapis.com">
<link rel="preconnect" href="https://fonts.gstatic.com" crossorigin>
{% endif %}

{% if font_settings.header_font and font_settings.header_font_family and font_settings.header_font_variant %}
    <link href="https://fonts.googleapis.com/css2?family={{font_settings.header_font_family}}:wght@300;400;700;900&display=swap" rel="stylesheet">
    <link rel="preload" as="font" href="{{ font_settings.header_font }}" type="font/woff2" crossorigin="anonymous">
{% endif %}

{% if font_settings.paragraph_font and font_settings.paragraph_font_family and font_settings.paragraph_font_variant %}
    <link href="https://fonts.googleapis.com/css2?family={{font_settings.paragraph_font_family}}:wght@300;400;700;900&display=swap" rel="stylesheet">
    <link rel="preload" as="font" href="{{ font_settings.paragraph_font }}" type="font/woff2" crossorigin="anonymous">
{% endif %}
