# Generated by Django 4.2.11 on 2025-05-01 09:47

from django.db import migrations, models
from oxyan.themes.definitions import theme

class Migration(migrations.Migration):

    dependencies = [
        ("coyote", "0017_stylesettings_body_color_stylesettings_border_radius"),
    ]

    operations = [
        migrations.AlterField(
            model_name="stylesettings",
            name="border_radius",
            field=models.DecimalField(decimal_places=2, default=theme["border-radius"], max_digits=6),
        ),
    ]
