<div class="coyote_field {% if child.block.required %}required{% endif %}" data-contentpath="{{ child.block.name }}">
    {% if child.block.label %}
        <label class="coyote_field__label" {% if child.id_for_label %}for="{{ child.id_for_label }}"{% endif %}>{{ child.block.label }}</label>
    {% endif %}
    {{ child.render_form }}
</div>