<div style="display: flex; flex-direction: row; flex-wrap: wrap; gap: 2rem;">
{% for child in children.values %}
	{% include "coyote/formtemplates/partials/inline_form_field.html" with child=child %}
{% endfor %}
</div>
