from importlib import import_module

from django.apps import AppConfig


class OcyanPluginCoyoteAppConfig(AppConfig):
    name = "ocyan.plugin.coyote"
    label = "coyote"

    def ready(self):
        import_module(f"{self.name}.signals")
