.iconslider-wrapper{
	@extend .coyote-block-wrapper;
	
	.tns-outer{
		position: relative;
		&:before, &:after{
			content: "" !important;
			position: absolute;
			top: 0;
			z-index: 3;
			display: block;
			height: 100%;
			pointer-events: none;
		}
		&:before{
			left: 0;
			background: linear-gradient(to right, var(--background), transparent);
			width: 50px;
		}
		&:after{
			right: 0;
			background: linear-gradient(to left, var(--background), transparent);
			width: 100px;
		}
	}
	.iconslider{
		.tns-item{
	        padding-right: ($cy-spacer * 1);
			img{
				width: 100%;
				height: 150px;
				object-fit: contain;
				object-position: center;
				filter: grayscale(100%);
				transition: .5s ease;
			}
			&:hover{
				img{
					filter: grayscale(0);
				}
			}
		}
	}
	.icon-wrapper{
		display: flex;
		justify-content: center;
		align-items: center;
		& > div{
			padding: 0 1rem;
			width: 20%;
		}
		img{
			width: 100%;
			height: 150px;
			object-fit: contain;
			object-position: center;
			filter: grayscale(100%);
			transition: .5s ease;
		}
		&:hover{
			img{
				filter: grayscale(0);
			}
		}
	}
}