# Generated by Django 4.2.11 on 2025-02-19 16:00

from django.db import migrations, models


class Migration(migrations.Migration):

    dependencies = [
        ("coyote", "0015_stylesettings_header_font_and_more"),
    ]

    operations = [
        migrations.AlterField(
            model_name="stylesettings",
            name="header_font_variant",
            field=models.CharField(default="", max_length=255),
        ),
        migrations.AlterField(
            model_name="stylesettings",
            name="paragraph_font_variant",
            field=models.CharField(default="", max_length=255),
        ),
    ]
