from django import template
from django.template.loader import render_to_string

from ..definitions import get_style_settings

register = template.Library()


@register.simple_tag()
def load_fonts():
    font_settings = get_style_settings()
    return render_to_string(
        "coyote/partials/fonts.html", {"font_settings": font_settings}
    )
